@@ -1,7 +1,7 @@
 package App::DuckPAN::Cmd::New;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Take a name as input and generates a new, named Goodie or Spice instant answer skeleton
-$App::DuckPAN::Cmd::New::VERSION = '0.192';
+$App::DuckPAN::Cmd::New::VERSION = '0.193';
 # For Goodies:
 # 	- <name>.pm file is created in lib/DDG/Goodie
 #
@@ -26,7 +26,7 @@ sub run {
 	my $type = $self->app->get_ia_type();
 
 	# Instant Answer name as parameter
-	my $entered_name = (@args) ? join(' ', @args) : $self->app->get_reply('Please enter a name for your Instant Answer');
+	my $entered_name = (@args) ? join(' ', @args) : $self->app->get_reply('Please enter a name for your Instant Answer: ');
 	$self->app->emit_and_exit(-1, "Must supply a name for your Instant Answer.") unless $entered_name;
 	$entered_name =~ s/\//::/g;    #change "/" to "::" for easier handling
 	my $name = $self->app->phrase_to_camel($entered_name);
@@ -93,7 +93,7 @@ App::DuckPAN::Cmd::New - Take a name as input and generates a new, named Goodie
 
 =head1 VERSION
 
-version 0.192
+version 0.193
 
 =head1 AUTHOR
 
